@@ -6,7 +6,7 @@ db = SQLAlchemy()
 Model = db.Model
 
 
-def get_model_with_table_name(table_name):
+def model_from_table_name(table_name):
     for model in Model._decl_class_registry.values():
         if not hasattr(model, '__table__'):
             continue
